@@ -1,10 +1,10 @@
 import glob
-from collections import OrderedDict
+from collections import OrderedDict, Counter
+from pathlib import Path
+from statistics import median
 
 import numpy as np
 import pandas as pd
-from pathlib import Path
-
 from scipy.io import arff
 from sklearn.preprocessing import LabelEncoder
 from sklearn.utils import Bunch
@@ -68,7 +68,6 @@ def load_arff_dataset(path: str, one_hot_encode: bool = True, return_non_cat_len
     mean = df.filter(non_categorical_cols).mean()
 
     df[categorical_cols] = df.filter(categorical_cols).fillna(mode)
-    df[categorical_cols] = df[categorical_cols].astype(int)
     df[non_categorical_cols] = df.filter(non_categorical_cols).fillna(mean)
 
     if one_hot_encode:
@@ -93,9 +92,54 @@ def load_datasets_arff(return_non_cat_length=False, dataset_paths=None):
         dataset_name = dataset_file.split('.')[0]
         if return_non_cat_length:
             X, y, cat_length = load_arff_dataset(path, return_non_cat_length=return_non_cat_length)
-            datasets[dataset_name] = Bunch(data=X, target=y, cat_length=cat_length, DESCR=dataset_name)
+            datasets[dataset_name] = Bunch(data=X, target=y, non_cat_length=cat_length, DESCR=dataset_name)
         else:
             X, y = load_arff_dataset(path, return_non_cat_length=return_non_cat_length)
             datasets[dataset_name] = Bunch(data=X, target=y, DESCR=dataset_name)
 
     return datasets
+
+
+def construct_maj_int_min(y: np.ndarray, strategy='median') -> OrderedDict:
+    """
+    This function creates dictionary with information which classes are minority or majority
+
+    :param y:
+        One dimensional numpy array that contains class labels
+    :param strategy:
+        The principle according to which the division into minority and majority classes will be determined:
+
+        * 'median':
+            A class whose size is equal to the median of the class sizes will be considered "intermediate"
+        * 'average':
+            The average class size will be calculated, all classes that are smaller will be considered as minority and
+            the rest will be considered majority
+    :return:
+        dictionary with keys 'maj', 'int', 'min. The value for each key is a list containing the class labels belonging
+        to the given group
+    """
+    class_sizes = Counter(y)
+
+    if strategy == 'median':
+        middle_size = median(list(class_sizes.values()))
+    elif strategy == 'average':
+        middle_size = np.mean(list(class_sizes.values()))
+    else:
+        raise ValueError(f'Unrecognized {strategy}. Only "median" and "average" are allowed.')
+
+    maj_int_min = OrderedDict({
+        'maj': list(),
+        'int': list(),
+        'min': list()
+    })
+    for class_label, class_size in class_sizes.items():
+        if class_size == middle_size:
+            class_group = 'int'
+        elif class_size < middle_size:
+            class_group = 'min'
+        else:
+            class_group = 'maj'
+
+        maj_int_min[class_group].append(class_label)
+
+    return maj_int_min
