@@ -5,15 +5,13 @@ def gmean_score(y_test, y_pred, correction: float = 0.001) -> float:  # pragma n
     """
     Calculate geometric mean score
 
-    Parameters
-    ----------
-    y_test numpy array with labels
-    y_pred numpy array with predicted labels
-    correction value that replaces 0 during multiplication to avoid zeroing the result
-
-    Returns
-    geometric_mean_score: float
-    -------
-
+    :param y_test:
+        numpy array with labels
+    :param y_pred:
+        numpy array with predicted labels
+    :param correction:
+        value that replaces 0 during multiplication to avoid zeroing the result
+    :return:
+        geometric_mean_score: float
     """
     return geometric_mean_score(y_test, y_pred, correction=correction)
